@@ -23,8 +23,8 @@
 
 #include <QObject>
 #include <QString>
-#include <QMap>
 #include <QSharedPointer>
+#include <QHash>
 
 #include "provider.h"
 #include "entryinternal.h"
@@ -58,6 +58,7 @@ class Provider;
 namespace KNSCore
 {
 class Cache;
+class CommentsModel;
 class Installation;
 
 /**
@@ -91,6 +92,13 @@ public:
      */
     bool init(const QString &configfile);
 
+    /**
+     * The name as defined by the knsrc file
+     * @return The name associated with the engine's configuration file
+     * @since 5.63
+     */
+    QString name() const;
+
     /**
      * Installs an entry's payload file. This includes verification, if
      * necessary, as well as decompression and other steps according to the
@@ -142,6 +150,12 @@ public:
      * @param mode The order you want search results to come back in.
      */
     void setSortMode(Provider::SortMode mode);
+    /**
+     * The sort mode set on the current request
+     * @see setSortMode(Provider::SortMode)
+     * @since 5.63
+     */
+    Provider::SortMode sortMode() const;
     /**
      * Set a filter for results (defaults to none), which will allow you
      * to show only installed entries, installed entries which have updates,
@@ -156,6 +170,12 @@ public:
      * @param filter The type of results you wish to see
      */
     void setFilter(Provider::Filter filter);
+    /**
+     * The result filter set on the current request
+     * @see setFilter(Provider::Filter)
+     * @since 5.63
+     */
+    Provider::Filter filter() const;
 
     /**
      * Set the categories that will be included in searches
@@ -176,6 +196,12 @@ public:
      * @param searchString The search term you wish to search for
      */
     void setSearchTerm(const QString &searchString);
+    /**
+     * The search term for the current search (empty if none is set)
+     * @return The current search term
+     * @since 5.63
+     */
+    QString searchTerm() const;
     void reloadEntries();
     void requestMoreData();
     void requestData(int page, int pageSize);
@@ -187,13 +213,19 @@ public:
      * setDownloadTagFilter(QStringList).
      *
      * @note The default filter if one is not set from your knsrc file will filter
-     * out entries marked as ghns_exclude=1. To retain this when setting a custom
-     * filter, add "ghns_exclude!=1" as one of the filters.
+     * out entries marked as ghns_excluded=1. To retain this when setting a custom
+     * filter, add "ghns_excluded!=1" as one of the filters.
      *
      * @note Some tags provided by OCS do not supply a value (and are simply passed
      * as a key). These will be interpreted as having the value 1 for filtering
-     * purposes. An example of this might be ghns_exclude, which in reality will
-     * generally be passed through ocs as "ghns_exclude" rather than "ghns_exclude=1"
+     * purposes. An example of this might be ghns_excluded, which in reality will
+     * generally be passed through ocs as "ghns_excluded" rather than "ghns_excluded=1"
+     *
+     * @note As tags are metadata, they are provided in the form of adjectives. They
+     * are never supplied as action verbs or instructions (as an example, a good tag
+     * to suggest that for example a wallpaper is painted would be "painted" as opposed
+     * to "paint", and another example might be that an item should be "excluded" as
+     * opposed to "exclude").
      *
      * == Examples of use ==
      * Value for tag "tagname" must be exactly "tagdata":
@@ -206,7 +238,7 @@ public:
      * A tag filter line in a .knsrc file, which is a comma semarated list of
      * tag/value pairs, might look like:
      *
-     * TagFilter=ghns_exclude!=1,data##mimetype==application/cbr+zip,data##mimetype==application/cbr+rar
+     * TagFilter=ghns_excluded!=1,data##mimetype==application/cbr+zip,data##mimetype==application/cbr+rar
      * which would honour the exclusion and filter out anything that does not
      * include a comic book archive in either zip or rar format in one or more
      * of the download items.
@@ -249,7 +281,7 @@ public:
      *
      * For an entry to be accepted when a download tag filter is set, it must also
      * be accepted by the entry filter (so, for example, while a list of downloads
-     * might be accepted, if the entry has ghns_exclude set, and the default entry
+     * might be accepted, if the entry has ghns_excluded set, and the default entry
      * filter is set, the entry will still be filtered out).
      *
      * In your knsrc file, set DownloadTagFilter to the filter you wish to apply,
@@ -371,7 +403,9 @@ public:
      * switch to a wallpaper or icon theme which was installed with KNS.
      *
      * The following is how this might look in a knsrc file. The example shows how
-     * an external tool is called on the installed file represented by %d.
+     * an external tool is called on the directory containing the installed file
+     * represented by %d. If you wish to directly point to the installed file, the
+     * substitution variable is %f.
      * <pre>
        AdoptionCommand=/usr/lib64/libexec/plasma-changeicons %d
      * </pre>
@@ -394,6 +428,55 @@ public:
      * @see requestData(int,int)
      */
     void setPageSize(int pageSize);
+
+    /**
+     * Get a list of all the locations which will be used when searching for knsrc
+     * files, in the order in which the search will occur.
+     *
+     * @param includeFallbackLocations Whether or not the deprecated search locations are included
+     * @return The search list for knsrc files
+     * @since 5.57
+     */
+    static QStringList configSearchLocations(bool includeFallbackLocations = false);
+    /**
+     * Sets whether or not the config file location discovery fallback should be active.
+     * If enabled (default), if the config file is not found in the knsrcfiles location,
+     * then the engine will also look in the systemwide config location (usually /etc/xdg
+     * on linux). If disabled, this fallback location will not be searched.
+     *
+     * @param enableFallback Whether or not the fallback discovery should be enabled
+     * @since 5.57
+     */
+    void setConfigLocationFallback(bool enableFallback);
+
+    /**
+     * The Provider instance with the passed ID
+     *
+     * @param providerId The ID of the Provider to fetch
+     * @return The Provider with the passed ID, or null if non such Provider exists
+     * @since 5.63
+     */
+    QSharedPointer<Provider> provider(const QString &providerId) const;
+
+    /**
+     * Return the first provider in the providers list (usually the default provider)
+     * @return The first Provider (or null if the engine is not initialized)
+     * @since 5.63
+     */
+    QSharedPointer<Provider> defaultProvider() const;
+
+    /**
+     * This function will return an instance of a model which contains comments for
+     * the entry passed to it. The model may be empty (if there are no comments for
+     * the entry, which also covers situations where the entry's provider does not
+     * support commenting)
+     *
+     * @param entry The entry to fetch comments for
+     * @return A model which contains the comments for the specified entry
+     * @since 5.63
+     */
+    CommentsModel *commentsForEntry(const KNSCore::EntryInternal &entry);
+
 Q_SIGNALS:
     /**
      * Indicates a message to be added to the ui's log, or sent to a messagebox
