@@ -17,13 +17,12 @@
 
 #include "entry.h"
 #include "entry_p.h"
+#include <knewstuff_debug.h>
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 using namespace KNS3;
 
-Q_LOGGING_CATEGORY(KNEWSTUFF, "knewstuff")
-
 Entry::Entry()
     : d(new EntryPrivate)
 {
@@ -108,25 +107,25 @@ static void appendIfValid(QList<QUrl>& list, const QUrl &value)
 QList<QUrl> KNS3::Entry::previewImages() const
 {
     QList<QUrl> ret;
-    appendIfValid(ret, QUrl(d->e.previewUrl(EntryInternal::PreviewBig1)));
-    appendIfValid(ret, QUrl(d->e.previewUrl(EntryInternal::PreviewBig2)));
-    appendIfValid(ret, QUrl(d->e.previewUrl(EntryInternal::PreviewBig3)));
+    appendIfValid(ret, QUrl(d->e.previewUrl(KNSCore::EntryInternal::PreviewBig1)));
+    appendIfValid(ret, QUrl(d->e.previewUrl(KNSCore::EntryInternal::PreviewBig2)));
+    appendIfValid(ret, QUrl(d->e.previewUrl(KNSCore::EntryInternal::PreviewBig3)));
     return ret;
 }
 
 QList<QUrl> KNS3::Entry::previewThumbnails() const
 {
     QList<QUrl> ret;
-    appendIfValid(ret, QUrl(d->e.previewUrl(EntryInternal::PreviewSmall1)));
-    appendIfValid(ret, QUrl(d->e.previewUrl(EntryInternal::PreviewSmall2)));
-    appendIfValid(ret, QUrl(d->e.previewUrl(EntryInternal::PreviewSmall3)));
+    appendIfValid(ret, QUrl(d->e.previewUrl(KNSCore::EntryInternal::PreviewSmall1)));
+    appendIfValid(ret, QUrl(d->e.previewUrl(KNSCore::EntryInternal::PreviewSmall2)));
+    appendIfValid(ret, QUrl(d->e.previewUrl(KNSCore::EntryInternal::PreviewSmall3)));
     return ret;
 }
 
 quint64 KNS3::Entry::size() const
 {
     const auto downloadInfo = d->e.downloadLinkInformationList();
-    return downloadInfo.at(0).size;
+    return downloadInfo.isEmpty() ? 0 : downloadInfo.at(0).size;
 }
 
 uint KNS3::Entry::numberOfComments() const
